@@ -215,16 +215,12 @@ public class Text extends HTMLPart {
 				continue;
 			}
 			spc_cnt = 0;
-			if ( line[i] == '"' ) {
-				buf = buf.append( "&quot;" );
+			WebChar	wc = WebChar.getWebChar( line[i] );
+			if ( wc != null ) {
+				buf = buf.append( wc.getRef() );
 				continue;
 			}
 			if ( mode != StringMode.ATTRIBUTE ) {
-				WebChar	wc = WebChar.getWebChar( line[i] );
-				if ( wc != null ) {
-					buf = buf.append( wc.getRef() );
-					continue;
-				}
 				if ( mode != StringMode.TEXTAREA ) {
 					if ( line[i] == '\n' || line[i] == '\r' ) {
 						if ( i > 0 ) {
