@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -24,7 +24,7 @@ import org.apache.commons.fileupload.servlet.*;
 /**
  * サイト制御。
  */
-public abstract class Supervisor extends HttpServlet {
+public abstract class Supervisor extends HttpServlet implements Cloneable {
 	/**
 	 * 不正リクエスト。
 	 */
@@ -69,11 +69,15 @@ public abstract class Supervisor extends HttpServlet {
 		SandBox.doStart();
 	}
 
+	private static Supervisor org_sv = null;
 	/**
 	 * コンストラクタ。
 	 */
 	public Supervisor() {
 		super();
+		if ( org_sv == null ) {
+			org_sv = this;
+		}
 	}
 
 	private static String resolvePage( DataHolder holder, String p ) {
@@ -747,38 +751,39 @@ public abstract class Supervisor extends HttpServlet {
 
 	protected final void doGet( HttpServletRequest req, HttpServletResponse res )  {
 		try {
-			Forward	fw = preset( RequestParameter.Method.GET, req, res );
-			if ( fw != null ) {
-				fw.Action( this, res );
-				return;
-			}
-			doAction( req, res );
-			synchronized( data_map_th ) {
-				data_map_th.remove( Thread.currentThread() );
-				data_map_sv.remove( this );
-			}
-		}
-		catch( Exception e ) {
-			onErrorDebug( e, req, res );
+			Supervisor	sv = (Supervisor)clone();
+			sv.doMain( RequestParameter.Method.GET, req, res );
 		}
+		catch( CloneNotSupportedException ce ){}
 	}
 
 	protected final void doPost( HttpServletRequest req, HttpServletResponse res )  {
+		try{
+			Supervisor	sv = (Supervisor)clone();
+			sv.doMain( RequestParameter.Method.POST, req, res );
+		}
+		catch( CloneNotSupportedException ce ){}
+	}
+
+	private void doMain( RequestParameter.Method m, HttpServletRequest req, HttpServletResponse res )  {
 		try {
-			Forward	fw = preset( RequestParameter.Method.POST, req, res );
+			Forward	fw = preset( m, req, res );
 			if ( fw != null ) {
 				fw.Action( this, res );
 				return;
 			}
 			doAction( req, res );
+		}
+		catch( Throwable e ) {
+			onErrorDebug( e, req, res );
+		}
+		finally {
 			synchronized( data_map_th ) {
 				data_map_th.remove( Thread.currentThread() );
 				data_map_sv.remove( this );
 			}
 		}
-		catch( Exception e ) {
-			onErrorDebug( e, req, res );
-		}
 	}
+
 }
 
